===========================================================================
``psyclone.domain.lfric.transformations.lfric_alg_invoke_2_psy_call_trans``
===========================================================================

.. automodule:: psyclone.domain.lfric.transformations.lfric_alg_invoke_2_psy_call_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.transformations.lfric_alg_invoke_2_psy_call_trans


Classes
=======

- :py:class:`LFRicAlgInvoke2PSyCallTrans`:
  Transforms an LFRicAlgorithmInvokeCall into a standard Call to a generated


.. autoclass:: LFRicAlgInvoke2PSyCallTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LFRicAlgInvoke2PSyCallTrans
      :parts: 1
